@@ -1,31 +1,17 @@
 package Net::GitHub;
 
-use Any::Moose;
+use Net::GitHub::V3;
 
-our $VERSION = '0.43_02';
+our $VERSION = '0.61_01';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 sub new {
     my $class = shift;
-    my $params = $class->BUILDARGS(@_);
-
-    my $obj;
-    if ( exists $params->{version} and $params->{version} == 2 ) {
-        warn "Github will terminate API v1 and API v2 in 1 month on May 1st, 2012\n";
-        require Net::GitHub::V2;
-        return Net::GitHub::V2->new($params);
-    } else {
-        require Net::GitHub::V3;
-        return Net::GitHub::V3->new($params);
-    }
-
-    #return $class->meta->new_object( __INSTANCE__ => $obj, @_,);
+    Net::GitHub::V3->new(@_);
 }
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-
 1;
+
 __END__
 
 =head1 NAME
@@ -36,24 +22,21 @@ Net::GitHub - Perl Interface for github.com
 
     use Net::GitHub;
 
-    # default to v3
     my $github = Net::GitHub->new(  # Net::GitHub::V3
         login => 'fayland', pass => 'secret'
     );
 
+    # Pass api_url for GitHub Enterprise installations
+    my $github = Net::GitHub->new(  # Net::GitHub::V3
+        login => 'fayland', pass => 'secret',  api_url => 'https://gits.aresweet.com/api/v3'
+    );
+
     # suggested
     # use OAuth to create token with user/pass
     my $github = Net::GitHub->new(  # Net::GitHub::V3
         access_token => $token
     );
 
-    # for backwards, NOTE: Github will terminate API v1 and API v2 in 1 month on May 1st, 2012
-    my $github = Net::GitHub->new(
-        version => 2,
-        owner => 'fayland', name => 'perl-net-github'
-    );
-
-    # for V3
     # L<Net::GitHub::V3::Users>
     my $user = $github->user->show('nothingmuch');
     $github->user->update( bio => 'Just Another Perl Programmer' );
@@ -106,7 +89,7 @@ L<http://github.com/fayland/perl-net-github/>
 
 =head1 SEE ALSO
 
-L<Any::Moose>, L<Pithub>
+L<Pithub>
 
 =head1 AUTHOR
 
